import { FormattedTime, OptionalOptions } from './types/common';
/**
 * Converts seconds to time format.
 *
 * @param seconds The seconds to convert.
 *
 * @return An object that that contains the `formattedTime` and the
 * `raw` values used to calculate the time.
 */
declare function formatTime(seconds: number): FormattedTime;
/**
 * Converts seconds to time format.
 *
 * @param seconds The seconds to convert.
 * @param options The options to build the string.
 *
 * Accepts a full options object passed into `create` but only uses `formatOuput` and `formatValues`
 *
 * @return {Object} An object that that contains the `formattedTime` and the
 * `raw` values used to calculate the time.
 */
declare function formatTime(seconds: number, options: OptionalOptions): FormattedTime;
/**
 * Converts seconds to time format.
 *
 * @param seconds The seconds to convert.
 * @param [options] The options to build the string.
 *
 * Accepts a full options object passed into `create` but only uses `formatOuput` and `formatValues`
 * @param [toBuild=true] Specifies wether to run the buildOptions function or not.
 *
 * For example, if you don't have a fully formed options object to pass in, or none at all.
 * Primarily used in `Timr#formatTime` to avoid making unnecessary calls to buildOptions on every tick.
 *
 * Setting to false will require `options.formatOuput` and `options.formatValues` to exist
 *
 * @return An object that that contains the `formattedTime` and the
 * `raw` values used to calculate the time.
 */
declare function formatTime(seconds: number, options?: OptionalOptions, toBuild?: boolean): FormattedTime;
export default formatTime;
