/**
 * Checks if a value is a valid number. Guards against NaN and Infinity.
 *
 * @param {any} value the value to be checked
 *
 * @return {boolean} True if it is, false if it isn't
 */
declare function isNum(value: any): value is number;
/**
 * Checks if a value is a not a number.
 *
 * @param {any} value the value to be checked
 *
 * @return {boolean} True if it is, false if it isn't
 */
declare function isNotNum(value: any): boolean;
/**
 * Checks if a value is a string.
 *
 * @param {any} value the value to be checked
 *
 * @return {boolean} True if it is, false if it isn't
 */
declare function isStr(value: any): value is string;
/**
 * Checks if a value is not a string.
 *
 * @param {any} value the value to be checked
 *
 * @return {boolean} True if it is, false if it isn't
 */
declare function isNotStr(value: any): boolean;
/**
 * Checks if a value is a boolean.
 *
 * @param {any} value the value to be checked
 *
 * @return {boolean} True if it is, false if it isn't
 */
declare function isBool(value: any): value is boolean;
/**
 * Checks if a value is not a boolean.
 *
 * @param {any} value the value to be checked
 *
 * @return {boolean} True if it is, false if it isn't
 */
declare function isNotBool(value: any): boolean;
/**
 * Checks if a value is a function.
 *
 * @param {any} value the value to be checked
 *
 * @return {boolean} True if it is, false if it isn't
 */
declare function isFn<T>(value: any): value is T;
/**
 * Checks if a value is not a function.
 *
 * @param {any} value the value to be checked
 *
 * @return {boolean} True if it is, false if it isn't
 */
declare function isNotFn<T>(value: any): boolean;
/**
 * Checks if a value is an object. Guards against null and arrays.
 *
 * @param {any} value the value to be checked
 *
 * @return {boolean} True if it is, false if it isn't
 */
declare function isObj<T>(value: any): value is T;
/**
 * Checks if a value is not an object.
 *
 * @param {any} value the value to be checked
 *
 * @return {boolean} True if it is, false if it isn't
 */
declare function isNotObj<T>(value: any): boolean;
/**
 * Checks if the provided object extends the provided class
 *
 * @param {value} value the value to be checked
 * @param {any} clazz the class to check against
 *
 * @return True if it is, false if it isn't
 */
declare function isInstanceOf<T>(value: any, clazz: any): value is T;
/**
 * Checks if the provided object does not extend the provided class
 *
 * @param {value} value the value to be checked
 * @param {any} clazz the class to check against
 *
 *  True if it is, false if it isn't
 */
declare function isNotOfObj<T>(value: T, clazz: any): boolean;
/**
 * Checks if a value exists, i.e. not undefined or null.
 *
 * @param {any} value the value to be checked
 *
 * @return {boolean} True if it is, false if it isn't
 */
declare function exists<T>(value: T | undefined | null): value is T;
/**
 * Checks if a value doesn't exist, i.e is undefined.
 *
 * @param {any} value the value to be checked
 *
 * @return {boolean} True if it is, false if it isn't
 */
declare function notExists(value: any): boolean;
/**
 * A more useful type check than typeof.
 * Guards against gotchas like null and array being an object and NaN being a number.
 * For this purpose it also explicitly states Infinity as a type rather than a number.
 *
 * @param {any} value The value to check the type of.
 *
 * @return {string|null} The type of the value.
 */
declare function checkType(value: any): string;
export { isNum, isNotNum, isStr, isNotStr, isBool, isNotBool, isFn, isNotFn, isObj, isNotObj, isInstanceOf, isNotOfObj, exists, notExists, checkType };
